.. _command:

Command
=======

Base
----

.. autoclass:: molecule.command.base.InvalidHost
   :members:

.. autoclass:: molecule.command.base.Base
   :members:

Check
-----

.. autoclass:: molecule.command.converge.Check
   :members:

Converge
--------

.. autoclass:: molecule.command.converge.Converge
   :members:

Create
------

.. autoclass:: molecule.command.create.Create
   :members:

Destroy
-------

.. autoclass:: molecule.command.destroy.Destroy
   :members:

Idempotence
-----------

.. autoclass:: molecule.command.idempotence.Idempotence
   :members:

Init
----

.. autoclass:: molecule.command.init.Init
   :members:

List
----

.. autoclass:: molecule.command.list.List
   :members:

Login
-----

.. autoclass:: molecule.command.login.Login
   :members:

Status
------

.. autoclass:: molecule.command.status.Status
   :members:

Syntax
------

.. autoclass:: molecule.command.syntax.Syntax
   :members:

Test
----

.. autoclass:: molecule.command.test.Test
   :members:

Verify
------

.. autoclass:: molecule.command.verify.Verify
   :members:
